package noOntoSearch;

import java.io.IOException;
import java.util.ArrayList;

import org.apache.lucene.document.Document;
import org.apache.lucene.index.IndexReader;
import org.apache.lucene.index.Term;
import org.apache.lucene.search.BooleanClause;
import org.apache.lucene.search.BooleanQuery;
import org.apache.lucene.search.Hits;
import org.apache.lucene.search.IndexSearcher;
import org.apache.lucene.search.PhraseQuery;
import org.apache.lucene.analysis.PorterStemmer;

public class PhraseSearcher {


	public PhraseSearcher() {}

	public void searchForPhrase(ArrayList phrases)
	{
		BooleanQuery bq = null;
		try {
			PorterStemmer stemmer = new PorterStemmer();
			IndexReader ir = IndexReader.open(Globals.indexDirectory);
			IndexSearcher	searcher = new IndexSearcher(ir);

			bq = new BooleanQuery();
			for(int i = 0; i < phrases.size();i++)
			{
				Phrase phrase = (Phrase)phrases.get(i);
				PhraseQuery pq = new PhraseQuery();
				for(int j = 0; j < phrase.getWords().length;j++)
				{
				pq.add(new Term(Globals.contentFieldName,
					stemmer.stem(phrase.getWords()[j])));
				}
				pq.setBoost(phrase.getBoost());
				bq.add(pq,BooleanClause.Occur.SHOULD);
			}
			Hits hits = searcher.search(bq);
			System.out.println("Antall treff: "+hits.length());
			for(int i = 0; i < hits.length(); i++)
			{
				Document doc = hits.doc(i);
				System.out.println("Fikk treff i dokument: "
				  +doc.getField(Globals.filenameFieldName).stringValue());
				System.out.println("Score: "+ hits.score(i));
			}

		}
		catch (IOException e)
		{
			e.printStackTrace();
		}
	}
	public static void main(String[] args)
	{
		Indexer indexer = new Indexer();
		indexer.indexFiles("c:\\ontosearch\\ontosearch\\dok\\docs\\");
		PhraseSearcher searcher = new PhraseSearcher();
		searcher.searchForPhrase(searcher.GetTestSet3());
	}
	public ArrayList GetTestSet1()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("cost estimating",1.5f));
		phrases.add(new Phrase("resource planning",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet2()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("cost estimating",1.5f));
		phrases.add(new Phrase("estimate at completion",1.0f));
		phrases.add(new Phrase("eac",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet3()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("human resource",1.5f));
		phrases.add(new Phrase("hr",1.5f));
		phrases.add(new Phrase("organizational planning",1.0f));
		phrases.add(new Phrase("staff",1.0f));
		phrases.add(new Phrase("staff acquisition",1.0f));
		phrases.add(new Phrase("team development",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet4()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("human resource",1.5f));
		phrases.add(new Phrase("staff",1.0f));
		phrases.add(new Phrase("human resource management",1.0f));
		phrases.add(new Phrase("organizational chart",1.0f));
		phrases.add(new Phrase("role",1.0f));
		phrases.add(new Phrase("staff assignment",1.0f));
		phrases.add(new Phrase("team competencies",1.0f));
		phrases.add(new Phrase("team development",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet5()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("stakeholder",1.5f));
		phrases.add(new Phrase("buyer",1.0f));
		phrases.add(new Phrase("customer",1.0f));
		phrases.add(new Phrase("external stakeholder",1.0f));
		phrases.add(new Phrase("internal stakeholder",1.0f));
		phrases.add(new Phrase("project staff",1.0f));
		phrases.add(new Phrase("seller",1.0f));
		phrases.add(new Phrase("vendor",1.0f));
		phrases.add(new Phrase("supplier",1.0f));
		phrases.add(new Phrase("subcontractor",1.0f));
		phrases.add(new Phrase("sponsor",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet6()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("stakeholder",1.5f));
		phrases.add(new Phrase("buyer",1.0f));
		phrases.add(new Phrase("seller",1.0f));
		return phrases;
	}

	public ArrayList GetTestSet7()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("procurement",1.5f));
		phrases.add(new Phrase("bidder conference",1.0f));
		phrases.add(new Phrase("vendor conference",1.0f));
		phrases.add(new Phrase("contractor conference",1.0f));
		phrases.add(new Phrase("pre-bid conference",1.0f));
		phrases.add(new Phrase("contract",1.0f));
		phrases.add(new Phrase("procurement planning",1.0f));
		phrases.add(new Phrase("solicitation",1.0f));
		phrases.add(new Phrase("source selection",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet8()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("procurement",1.5f));
		phrases.add(new Phrase("contract administration",1.0f));
		phrases.add(new Phrase("contract closeout",1.0f));
		phrases.add(new Phrase("procurement item",1.0f));
		phrases.add(new Phrase("procurement management",1.0f));
		phrases.add(new Phrase("procurement management plan",1.0f));
		phrases.add(new Phrase("procurement planning",1.0f));
		phrases.add(new Phrase("proposal",1.0f));
		phrases.add(new Phrase("solicitation planning",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet9()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("risk response",1.5f));
		phrases.add(new Phrase("risk response plan",1.0f));
		phrases.add(new Phrase("risk register",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet10()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("risk response",1.5f));
		phrases.add(new Phrase("risk response plan",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet11()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("work breakdown structure",1.5f));
		phrases.add(new Phrase("wbs",1.5f));

		return phrases;
	}

	public ArrayList GetTestSet12()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("work breakdown structure",1.5f));
		phrases.add(new Phrase("breakdown structure",1.5f));

		return phrases;
	}

	public ArrayList GetTestSet13()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("earned value",1.5f));
		phrases.add(new Phrase("budget cost of work performed",1.5f));
		phrases.add(new Phrase("bcwp",1.5f));
		phrases.add(new Phrase("ev",1.5f));
		phrases.add(new Phrase("actual cost",1.0f));
		phrases.add(new Phrase("planned value",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet14()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("earned value",1.5f));
		phrases.add(new Phrase("ev",1.5f));

		return phrases;
	}

	public ArrayList GetTestSet15()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("earned value management",1.5f));
		phrases.add(new Phrase("evm",1.5f));
		phrases.add(new Phrase("control account plan",1.0f));
		phrases.add(new Phrase("earned value",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet16()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("earned value management",1.5f));
		phrases.add(new Phrase("evm",1.5f));

		return phrases;
	}

	public ArrayList GetTestSet17()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("communications management",1.5f));
		phrases.add(new Phrase("communications management plan",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet18()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("communications management",1.5f));
		phrases.add(new Phrase("communications management plan",1.0f));
		phrases.add(new Phrase("communications management figure",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet19()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("performance",1.5f));
		phrases.add(new Phrase("performance measurement",1.0f));
		phrases.add(new Phrase("performance reporting",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet20()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("performance",1.5f));
		phrases.add(new Phrase("team performance",1.0f));
		phrases.add(new Phrase("performance reporting",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet21()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("planning process",1.5f));
		phrases.add(new Phrase("core process",1.0f));
		phrases.add(new Phrase("facilitating process",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet22()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("planning process",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet23()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("control account plan",1.5f));
		phrases.add(new Phrase("cost account plan",1.5f));
		phrases.add(new Phrase("cap",1.5f));

		return phrases;
	}

	public ArrayList GetTestSet24()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("control account plan",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet25()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("project management information system",1.5f));
		phrases.add(new Phrase("pmis",1.5f));

		return phrases;
	}

	public ArrayList GetTestSet26()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("project management information system",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet27()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("time management",1.5f));
		phrases.add(new Phrase("activity",1.0f));
		phrases.add(new Phrase("schedule development",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet28()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("time management",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet29()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("integration management",1.5f));
		phrases.add(new Phrase("integration change control",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet30()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("integration management",1.0f));

		return phrases;
	}

	public ArrayList GetTestSet31()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("cost performance index",1.5f));
		phrases.add(new Phrase("cpi",1.5f));

		return phrases;
	}

	public ArrayList GetTestSet32()
	{
		ArrayList phrases = new ArrayList();
		phrases.add(new Phrase("cost performance index",1.0f));

		return phrases;
	}

}
